@@ -20,17 +20,17 @@
 import logging
 import sys
 from io import StringIO
-from typing import (Callable, Iterable, Iterator, List, Optional, TextIO,
-                    Tuple, Union)
+from typing import Callable, Iterable, Iterator, List, Optional, TextIO, Tuple, Union
 from urllib.parse import urljoin
 
 import pcre2
+
 from debian.changelog import Version
 
 from . import __version__
 from .reformatting import Editor
 
-DEFAULT_USER_AGENT = 'debmutate/%s' % '.'.join([str(x) for x in __version__])
+DEFAULT_USER_AGENT = "debmutate/{}".format(".".join([str(x) for x in __version__]))
 
 DEFAULT_VERSION: int = 4
 
@@ -39,29 +39,30 @@ SUBSTITUTIONS = {
     # of the debian/changelog file.
     # '@PACKAGE@': None,
     # This is substituted by the legal upstream version regex (capturing).
-    '@ANY_VERSION@': r'[-_]?(\d[\-+\.:\~\da-zA-Z]*)',
+    "@ANY_VERSION@": r"[-_]?(\d[\-+\.:\~\da-zA-Z]*)",
     # This is substituted by the typical archive file extension regex
     # (non-capturing).
-    '@ARCHIVE_EXT@': r'(?i)\.(?:tar\.xz|tar\.bz2|tar\.gz|zip|tgz|tbz|txz)',
+    "@ARCHIVE_EXT@": r"(?i)\.(?:tar\.xz|tar\.bz2|tar\.gz|zip|tgz|tbz|txz)",
     # This is substituted by the typical signature file extension regex
     # (non-capturing).
-    '@SIGNATURE_EXT@':
-        r'(?i)\.(?:tar\.xz|tar\.bz2|tar\.gz|zip|tgz|tbz|txz)'
-        r'\.(?:asc|pgp|gpg|sig|sign)',
+    "@SIGNATURE_EXT@": r"(?i)\.(?:tar\.xz|tar\.bz2|tar\.gz|zip|tgz|tbz|txz)"
+    r"\.(?:asc|pgp|gpg|sig|sign)",
     # This is substituted by the typical Debian extension regexp (capturing).
-    '@DEB_EXT@': r'[\+~](debian|dfsg|ds|deb)(\.)?(\d+)?$',
+    "@DEB_EXT@": r"[\+~](debian|dfsg|ds|deb)(\.)?(\d+)?$",
 }
 
 
 class InvalidUVersionMangle(ValueError):
-    """uversionmangle is invalid"""
+    """uversionmangle is invalid."""
 
 
 class WatchFile:
-
-    def __init__(self, entries: Optional[List['Watch']] = None,
-                 options: Optional[List[str]] = None,
-                 version: int = DEFAULT_VERSION) -> None:
+    def __init__(
+        self,
+        entries: Optional[List["Watch"]] = None,
+        options: Optional[List[str]] = None,
+        version: int = DEFAULT_VERSION,
+    ) -> None:
         self.version = version
         if entries is None:
             entries = []
@@ -73,7 +74,7 @@ class WatchFile:
     def get_option(self, name):
         for option in self.options:
             try:
-                key, value = option.split('=', 1)
+                key, value = option.split("=", 1)
             except ValueError:
                 key = option
                 value = None
@@ -85,10 +86,10 @@ class WatchFile:
         if newvalue is None:
             nv = name
         else:
-            nv = '{}={}'.format(name, newvalue)
+            nv = f"{name}={newvalue}"
         for i, option in enumerate(self.options):
             try:
-                key, value = option.split('=', 1)
+                key, value = option.split("=", 1)
             except ValueError:
                 key = option
                 value = None
@@ -100,7 +101,7 @@ class WatchFile:
     def del_option(self, name):
         for i, option in enumerate(self.options):
             try:
-                key, value = option.split('=', 1)
+                key, value = option.split("=", 1)
             except ValueError:
                 key = option
             if key == name:
@@ -108,54 +109,57 @@ class WatchFile:
                 return
         raise KeyError(name)
 
-    def __iter__(self) -> Iterator['Watch']:
+    def __iter__(self) -> Iterator["Watch"]:
         return iter(self.entries)
 
     def __bool__(self) -> bool:
         return bool(self.entries)
 
     def __eq__(self, other: object) -> bool:
-        return isinstance(other, type(self)) and \
-                self.entries == other.entries and \
-                self.options == other.options and \
-                self.version == other.version
+        return (
+            isinstance(other, type(self))
+            and self.entries == other.entries
+            and self.options == other.options
+            and self.version == other.version
+        )
 
     def dump(self, f: TextIO) -> None:
         def serialize_options(opts: List[str]) -> str:
-            s = ','.join(opts)
-            if ' ' in s or '\t' in s:
+            s = ",".join(opts)
+            if " " in s or "\t" in s:
                 return 'opts="' + s + '"'
-            return 'opts=' + s
-        f.write('version=%d\n' % self.version)
+            return "opts=" + s
+
+        f.write("version=%d\n" % self.version)
         if self.options:
-            f.write(serialize_options(self.options) + '\n')
+            f.write(serialize_options(self.options) + "\n")
         for entry in self.entries:
             if entry.options:
-                f.write(serialize_options(entry.options) + ' ')
+                f.write(serialize_options(entry.options) + " ")
             f.write(entry.url)
             if entry.matching_pattern:
-                f.write(' ' + entry.matching_pattern)
+                f.write(" " + entry.matching_pattern)
             if entry.version:
-                f.write(' ' + entry.version)
+                f.write(" " + entry.version)
             if entry.script:
-                f.write(' ' + entry.script)
-            f.write('\n')
+                f.write(" " + entry.script)
+            f.write("\n")
 
 
 def parse_sed_expr(vm):
-    if vm.startswith('s'):
-        return ('s', parse_subst_expr(vm))
-    if vm.startswith('tr'):
-        return ('tr', parse_transl_expr(vm))
-    if vm.startswith('y'):
-        return ('y', parse_transl_expr(vm))
-    raise InvalidUVersionMangle(vm, 'not a substitution or translation regex')
+    if vm.startswith("s"):
+        return ("s", parse_subst_expr(vm))
+    if vm.startswith("tr"):
+        return ("tr", parse_transl_expr(vm))
+    if vm.startswith("y"):
+        return ("y", parse_transl_expr(vm))
+    raise InvalidUVersionMangle(vm, "not a substitution or translation regex")
 
 
 def parse_subst_expr(vm: str) -> Tuple[str, str, Optional[str]]:
-    if vm[0] != 's':
-        raise InvalidUVersionMangle(vm, 'not a substitution regex')
-    parts = pcre2.split(r'(?<!\\)' + vm[1], vm)
+    if vm[0] != "s":
+        raise InvalidUVersionMangle(vm, "not a substitution regex")
+    parts = pcre2.split(r"(?<!\\)" + vm[1], vm)
     if len(parts) < 3:
         raise InvalidUVersionMangle(vm)
     pattern = parts[1]
@@ -169,13 +173,13 @@ def parse_subst_expr(vm: str) -> Tuple[str, str, Optional[str]]:
 
 
 def parse_transl_expr(vm: str) -> Tuple[str, str, Optional[str]]:
-    if vm.startswith('tr'):
+    if vm.startswith("tr"):
         s = vm[2:]
-    elif vm.startswith('y'):
+    elif vm.startswith("y"):
         s = vm[1:]
     else:
-        raise InvalidUVersionMangle(vm, 'not a translation regex')
-    parts = pcre2.split(r'(?<!\\)' + s[0], vm)
+        raise InvalidUVersionMangle(vm, "not a translation regex")
+    parts = pcre2.split(r"(?<!\\)" + s[0], vm)
     if len(parts) < 3:
         raise InvalidUVersionMangle(vm)
     pattern = parts[1]
@@ -190,15 +194,17 @@ def parse_transl_expr(vm: str) -> Tuple[str, str, Optional[str]]:
 
 def apply_sed_expr(vm: str, orig: str) -> str:
     (kind, (pattern, replacement, flags)) = parse_sed_expr(vm)
-    if kind == 's':
+    if kind == "s":
         # TODO(jelmer): Handle flags
         return pcre2.substitute(pattern, replacement, orig)
-    elif kind == 'tr':
+    elif kind == "tr":
         from tr import tr
-        return tr(pattern, replacement, orig, flags or '')
-    elif kind == 'y':
+
+        return tr(pattern, replacement, orig, flags or "")
+    elif kind == "y":
         from tr import tr
-        return tr(pattern, replacement, orig, flags or '')
+
+        return tr(pattern, replacement, orig, flags or "")
     else:
         raise ValueError(kind)
 
@@ -216,34 +222,31 @@ class Release:
         self.pgpsigurl = pgpsigurl
 
     def __lt__(self, other):
-        if type(self) != type(other):
+        if type(self) is not type(other):
             raise TypeError(other)
         return Version(self.version) < Version(other.version)
 
     def __repr__(self):
-        return "{}({!r}, {!r}, pgpsigurl={!r})".format(
-            type(self).__name__, self.version, self.url,
-            self.pgpsigurl)
+        return f"{type(self).__name__}({self.version!r}, {self.url!r}, pgpsigurl={self.pgpsigurl!r})"
 
 
 def html_search(body, matching_pattern, base_url):
     from bs4 import BeautifulSoup
-    soup = BeautifulSoup(body, 'html.parser')
-    if '/' not in matching_pattern:
-        matching_pattern = urljoin(
-            base_url.rstrip('/') + '/', matching_pattern)
-    for a in soup.find_all('a'):
-        href = a.attrs.get('href')
+
+    soup = BeautifulSoup(body, "html.parser")
+    if "/" not in matching_pattern:
+        matching_pattern = urljoin(base_url.rstrip("/") + "/", matching_pattern)
+    for a in soup.find_all("a"):
+        href = a.attrs.get("href")
         if not href:
             continue
-        href = urljoin(base_url.rstrip('/') + '/', href)
+        href = urljoin(base_url.rstrip("/") + "/", href)
         m = pcre2.match(matching_pattern, href)
         if m:
-            logging.debug('Matched pattern %r to %r', matching_pattern, href)
+            logging.debug("Matched pattern %r to %r", matching_pattern, href)
             yield m
         else:
-            logging.debug(
-                'Did not match pattern %r to %r', matching_pattern, href)
+            logging.debug("Did not match pattern %r to %r", matching_pattern, href)
 
 
 def plain_search(body, matching_pattern, base_url):
@@ -251,27 +254,31 @@ def plain_search(body, matching_pattern, base_url):
 
 
 searchers = {
-    'plain': plain_search,
-    'html': html_search,
-    }
+    "plain": plain_search,
+    "html": html_search,
+}
 
 
 def _subst(text: str, package: Union[str, Callable[[], str]]):
     substs = dict(SUBSTITUTIONS)
-    if '@PACKAGE@' in text:
+    if "@PACKAGE@" in text:
         if callable(package):
             package = package()
-        substs['@PACKAGE@'] = package
+        substs["@PACKAGE@"] = package
     for k, v in substs.items():
         text = text.replace(k, v)
     return text
 
 
 class Watch:
-
-    def __init__(self, url: str, matching_pattern: Optional[str] = None,
-                 version: Optional[str] = None, script: Optional[str] = None,
-                 opts: Optional[List[str]] = None) -> None:
+    def __init__(
+        self,
+        url: str,
+        matching_pattern: Optional[str] = None,
+        version: Optional[str] = None,
+        script: Optional[str] = None,
+        opts: Optional[List[str]] = None,
+    ) -> None:
         self.url = url
         self.matching_pattern = matching_pattern
         self.version = version
@@ -282,19 +289,18 @@ class Watch:
 
     def uversionmangle(self, version):
         try:
-            vm = self.get_option('uversionmangle')
+            vm = self.get_option("uversionmangle")
         except KeyError:
             return version
         try:
             return apply_sed_expr(vm, version)
         except pcre2.exceptions.LibraryError as e:
-            raise WatchSyntaxError(
-                'invalid uversionmangle {!r}: {}'.format(vm, e)) from e
+            raise WatchSyntaxError(f"invalid uversionmangle {vm!r}: {e}") from e
 
     def get_option(self, name):
         for option in self.options:
             try:
-                key, value = option.split('=', 1)
+                key, value = option.split("=", 1)
             except ValueError:
                 key = option
                 value = None
@@ -313,10 +319,10 @@ class Watch:
         if newvalue is None:
             nv = name
         else:
-            nv = '{}={}'.format(name, newvalue)
+            nv = f"{name}={newvalue}"
         for i, option in enumerate(self.options):
             try:
-                key, value = option.split('=', 1)
+                key, value = option.split("=", 1)
             except ValueError:
                 key = option
                 value = None
@@ -328,7 +334,7 @@ class Watch:
     def del_option(self, name):
         for i, option in enumerate(self.options):
             try:
-                key, value = option.split('=', 1)
+                key, value = option.split("=", 1)
             except ValueError:
                 key = option
             if key == name:
@@ -338,45 +344,47 @@ class Watch:
 
     def __repr__(self) -> str:
         return (
-            ("{}({!r}, matching_pattern={!r}, "
-             "version={!r}, script={!r}, opts={!r})")
-            .format(
-                self.__class__.__name__, self.url, self.matching_pattern,
-                self.version, self.script, self.options))
+            f"{self.__class__.__name__}({self.url!r}, matching_pattern={self.matching_pattern!r}, "
+            f"version={self.version!r}, script={self.script!r}, opts={self.options!r})"
+        )
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, Watch):
             return False
-        return (other.url == self.url and
-                other.matching_pattern == self.matching_pattern and
-                other.version == self.version and
-                other.script == self.script and
-                other.options == self.options)
+        return (
+            other.url == self.url
+            and other.matching_pattern == self.matching_pattern
+            and other.version == self.version
+            and other.script == self.script
+            and other.options == self.options
+        )
 
     def format_url(self, package: Union[str, Callable[[], str]]) -> str:
         return _subst(self.url, package)
 
     def discover(self, package) -> Iterator[Release]:
         from urllib.request import Request, urlopen
+
         url = self.format_url(package)
         try:
-            user_agent = self.get_option('user-agent')
+            user_agent = self.get_option("user-agent")
         except KeyError:
             user_agent = DEFAULT_USER_AGENT
         try:
-            searchmode = self.get_option('searchmode')
+            searchmode = self.get_option("searchmode")
         except KeyError:
-            searchmode = 'html'
-        logging.debug('Fetching url %s; searchmode=%s', url, searchmode)
-        req = Request(url, headers={'User-Agent': user_agent})
+            searchmode = "html"
+        logging.debug("Fetching url %s; searchmode=%s", url, searchmode)
+        req = Request(url, headers={"User-Agent": user_agent})
         resp = urlopen(req)
         assert self.matching_pattern
         for m in searchers[searchmode](
-                resp.read(), _subst(self.matching_pattern, package), url):
+            resp.read(), _subst(self.matching_pattern, package), url
+        ):
             # TODO(jelmer): Apply uversionmangle
             full_url = urljoin(url, m.group(0))
             try:
-                pgpsigurlmangle = self.get_option('pgpsigurlmangle')
+                pgpsigurlmangle = self.get_option("pgpsigurlmangle")
             except KeyError:
                 pgpsigurl = None
             else:
@@ -402,28 +410,28 @@ def parse_watch_file(f: Iterable[str]) -> Optional[WatchFile]:
     lines: List[List[str]] = []
     continued: List[str] = []
     for line in f:
-        if line.startswith('#'):
+        if line.startswith("#"):
             continue
         if not line.strip():
             continue
-        if line.rstrip('\n').endswith('\\'):
-            continued.append(line.rstrip('\n\\'))
+        if line.rstrip("\n").endswith("\\"):
+            continued.append(line.rstrip("\n\\"))
         else:
             continued.append(line)
             lines.append(continued)
             continued = []
     if continued:
         # Hmm, broken line?
-        logging.warning('watchfile ended with \\; skipping last line')
+        logging.warning("watchfile ended with \\; skipping last line")
         lines.append(continued)
     if not lines:
         return None
-    firstline = ''.join(lines.pop(0))
+    firstline = "".join(lines.pop(0))
     try:
-        key, value = firstline.split('=', 1)
+        key, value = firstline.split("=", 1)
     except ValueError:
         raise MissingVersion()
-    if key.strip() != 'version':
+    if key.strip() != "version":
         raise MissingVersion()
     version = int(value.strip())
     persistent_options: List[str] = []
@@ -432,24 +440,24 @@ def parse_watch_file(f: Iterable[str]) -> Optional[WatchFile]:
     for chunked in lines:
         if version > 3:
             chunked = [chunk.lstrip() for chunk in chunked]
-        line = ''.join(chunked).strip()
+        line = "".join(chunked).strip()
         if not line:
             continue
         opts: Optional[List[str]]
-        if line.startswith('opts='):
+        if line.startswith("opts="):
             if line[5] == '"':
                 optend = line.index('"', 6)
                 if optend == -1:
-                    raise ValueError('Not matching " in %r' % line)
+                    raise ValueError(f'Not matching " in {line!r}')
                 opts_str = line[6:optend]
-                line = line[optend+1:]
+                line = line[optend + 1 :]
             else:
                 try:
                     (opts_str, line) = line[5:].split(maxsplit=1)
                 except ValueError:
                     opts_str = line[5:]
                     line = None
-            opts = opts_str.split(',')
+            opts = opts_str.split(",")
         else:
             opts = None
         if not line:
@@ -460,28 +468,28 @@ def parse_watch_file(f: Iterable[str]) -> Optional[WatchFile]:
                 url, line = line.split(maxsplit=1)
             except ValueError:
                 url = line
-                line = ''
-            m = pcre2.findall(r'/([^/]*\([^/]*\)[^/]*)$', url)
+                line = ""
+            m = pcre2.findall(r"/([^/]*\([^/]*\)[^/]*)$", url)
             if m:
                 parts = [m[0]] + line.split(maxsplit=1)
-                url = url[:-len(m[0])-1].strip()
+                url = url[: -len(m[0]) - 1].strip()
             else:
                 parts = line.split(maxsplit=2)
             entries.append(Watch(url, *parts, opts=opts))  # type: ignore
-    return WatchFile(
-        entries=entries, options=persistent_options, version=version)
+    return WatchFile(entries=entries, options=persistent_options, version=version)
 
 
 class WatchEditor(Editor[WatchFile, str]):
-
     _parsed: WatchFile
 
     def __init__(
-            self, path: str = 'debian/watch', *,
-            allow_reformatting: Optional[bool] = None,
-            allow_missing: bool = False) -> None:
-        super().__init__(
-            path, allow_reformatting=allow_reformatting)
+        self,
+        path: str = "debian/watch",
+        *,
+        allow_reformatting: Optional[bool] = None,
+        allow_missing: bool = False,
+    ) -> None:
+        super().__init__(path, allow_reformatting=allow_reformatting)
         self.allow_missing = allow_missing
 
     @property
@@ -509,27 +517,29 @@ class WatchEditor(Editor[WatchFile, str]):
 
 def uscan(wf, package):
     for entry in wf.entries:
-        logging.info('entry: %s' % entry)
+        logging.info(f"entry: {entry}")
         for d in entry.discover(package):
-            logging.info('  %s' % d)
+            logging.info(f"  {d}")
 
 
 def main(argv):
     import argparse
+
     parser = argparse.ArgumentParser()
-    parser.add_argument('--verbose', action='store_true')
+    parser.add_argument("--verbose", action="store_true")
     args = parser.parse_args()
     if args.verbose:
-        logging.basicConfig(level=logging.DEBUG, format='%(message)s')
+        logging.basicConfig(level=logging.DEBUG, format="%(message)s")
     else:
-        logging.basicConfig(level=logging.INFO, format='%(message)s')
-    with open('debian/watch') as f:
+        logging.basicConfig(level=logging.INFO, format="%(message)s")
+    with open("debian/watch") as f:
         wf = parse_watch_file(f)
     from debian.deb822 import Deb822
-    with open('debian/control') as f:
+
+    with open("debian/control") as f:
         source = Deb822(f)
-    uscan(wf, source['Source'])
+    uscan(wf, source["Source"])
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(main(sys.argv))
